@@ -49,30 +49,41 @@ for (i in first:last) {
   } #end loop
     #a few more tests
   
-  simple <- item.sim(nvar=24)
-  circ <-  circ.sim(nvar=24)
+  simple <- sim.item(nvar=24)
+  circ <-  sim.circ(nvar=24)
   simple.par <- fa.parallel(simple)
   fa.simple <- factor.pa(simple,2)
   fa.simple.keys <- ICLUST.sort(fa.simple,keys=TRUE)
  
  simple.scores <-  score.items(fa.simple.keys$clusters,simple)
   pairs.panels(simple.scores$scores)
-   f4 <- VSS.simulate()
+   f4 <- sim.VSS()
     psych.d <- NULL 
-   #the next test, phi.demo, throws multiple warnings that are from the polycor package and can not be found
+  #the next test, phi.demo, throws multiple warnings that are from the polycor package and can not be found
   #if (!require(polycor)) { warning("psycho.demo requires the polycor package")  psych.d <- NULL  } else  {psych.d <- phi.demo() } 
-  cong <- congeneric.sim()
+  cong <- sim.congeneric()
   
 
    
-   cluster.plot(factor.pa(circ.sim(nvar=24),nf=2),title="two circumplex factors")
+   cluster.plot(factor.pa(sim.circ(nvar=24),nf=2),title="two circumplex factors")
  pairs.panels(cong) 
-
+ #this section tests various functions that use Rgraphviz (if it is installed) 
  if(require(Rgraphviz)) { fa.graph(factor.pa(item.sim(16),2) ,title="Principal factor of a simple structure") 
   	ic.out <- ICLUST(s4,title="ICLUST of 24 Mental abilities")
-  	jen <-  omega(make.hierarchical(),title="Omega with Schmid Leihman")
+  	jen <-  omega(sim.hierarchical(),title="Omega with Schmid Leihman")
   	omega.graph(jen,sl=FALSE,title="Omega with hierarchical factors")
- } else {warning("fa.graph, omega.graph, ICLUST.rgraph require Rgraphviz") }
+  	   #set up the parameters for the structure graph
+		X6 <- matrix(c("a","b","c",rep(0,6),"d","e","f"),nrow=6)
+		colnames(X6) <- c("L1","L2")
+		rownames(X6) <- c("x1","x2","x3","x4","x5","x6")
+		Y3 <- matrix(c("u","w","z"),ncol=1)
+		colnames(Y3) <- "Y"
+		rownames(Y3) <- c("y1","y2","y3")
+		phi21 <- matrix(c(1,0,"r1",0,1,"r2",0,0,1),ncol=3)
+		colnames(phi21) <- rownames(phi21) <-  c("L1","L2","Y")
+	structure.graph(X6,phi21,Y3,title="Symbolic structural model")
+
+ } else {warning("fa.graph, omega.graph, ICLUST.rgraph, structure.graph require Rgraphviz") }
   
   out <- list(out,fa.simple,psych.d)
  if (!short) { return(out)}
